# pysml

Python library for EDL21 smart meters using Smart Message Language (SML)

Can read SML data from physical serial ports, serial-over-tcp or HTTP.

Used by Home Assistant's EDL21 integration.

There's [example code](examples/sml-mqtt-bridge.py) for publishing OBIS values to an MQTT broker.
